TerrainExtractor

Struct TerrainExtractor 

pub struct TerrainExtractor { /* private fields */ }

Implementations

Source

impl TerrainExtractor

pub fn queue_tile_extraction( &mut self, tile_pos: ChunkPos, map_type: u32, splat_map_index: u32, )

Queues a tile for extraction from the GPU. The tile will be processed in the next render pass and the extracted data will be available in the main world in the next frame.

Arguments
  • tile_pos - The position of the tile to extract (x, z)
  • map_type - The type of map to extract (0 for heightmap, 1 for splatmap)
  • splat_map_index - The index of the splat map to extract (only relevant if map_type is 1, should be between 0 and SPLAT_MAP_COUNT/4 - 1)
pub fn clear_tiles_to_extract(&mut self)

Clears the list of tiles to extract. Should be called after processing the extracted tiles to avoid extracting the same tiles multiple times.